==> nextcloud-31.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/photos/l10n/de.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Öffentlicher Link",
    "Photos" : "Fotos",
    "On This Day" : "An diesem Tag",
    "Your memories under your control" : "Deine Erinnerungen unter deiner Kontrolle",
    "All media" : "Alle Medien",
    "Videos" : "Videos",
    "Albums" : "Alben",
    "Collaborative albums" : "Gemeinsame Alben",
    "People" : "Personen",
    "Folders" : "Ordner",
    "Favorites" : "Favoriten",
    "On this day" : "An diesem Tag",
    "Shared with you" : "Mit dir geteilt",
    "Tags" : "Schlagworte",
    "Places" : "Orte",
    "Map" : "Karte",
    "Photos settings" : "Fotos-Einstellungen",
    "Mark selection as favorite" : "Auswahl als Favoriten markieren",
    "Add selection to favorites" : "Auswahl zu Favoriten hinzufügen",
    "Remove selection from favorites" : "Auswahl aus Favoriten entfernen",
    "Name of the album" : "Name des Albums",
    "Location of the album" : "Ort des Albums",
    "Back" : "Zurück",
    "Add collaborators" : "Mitbearbeitende hinzufügen",
    "Save" : "Speichern",
    "Create album" : "Album erstellen",
    "Add to Album" : "Zum Album hinzufügen",
    "Add selection to album {albumName}" : "Auswahl zum Album {albumName} hinzufügen",
    "Shared by" : "Geteilt von",
    "Create a new album." : "Ein neues Album erstellen",
    "Create new album" : "Neues Album erstellen",
    "New album" : "Neues Album",
    "_%n item_::_%n photos and videos_" : ["%n Foto oder Video","%n Fotos und Videos"],
    "Failed to fetch collaborators list." : "Liste der Mitbearbeitenden konnte nicht abgerufen werden.",
    "Failed to update album." : "Album konnte nicht aktualisiert werden.",
    "Add people or groups who can edit your album" : "Personen oder Gruppen hinzufügen, die dein Album bearbeiten können",
    "Search people or groups" : "Nach Benutzer oder Gruppen suchen",
    "No recommendations. Start typing." : "Keine Vorschläge, beginne mit der Eingabe.",
    "Group" : "Gruppe",
    "Remove {collaboratorLabel} from the collaborators list" : "{collaboratorLabel} aus der Liste der Mitarbeitenden löschen",
    "Copy the public link" : "Den öffentlichen Link kopieren",
    "Public link copied!" : "Öffentlicher Link kopiert",
    "Copy public link" : "Öffentlichen Link kopieren",
    "Delete the public link" : "Den öffentlichen Link löschen",
    "Create public link share" : "Öffentlichen Link zum Teilen erstellen",
    "Share via public link" : "Als öffentlichen Link teilen",
    "This collection does not exist" : "Diese Sammlung existiert nicht",
    "An error occurred" : "Es ist ein Fehler aufgetreten",
    "No picture for this day" : "Kein Bild für diesen Tag",
    "Picture taken on this day will show up here." : "Ein Bild, das an diesem Tag aufgenommen wurde, wird hier angezeigt.",
    "More photos from this day" : "Weitere Bilder von diesem Tag",
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n nicht zugewiesenes Foto","%n nicht zugewiesene Fotos"],
    "Favorite" : "Favorit",
    "Favorite image, open the full size \"{name}\" image" : "Favorisiertes Bild, öffne das Bild \"{name}\" in Originalgröße",
    "Open the full size \"{name}\" image" : "Bild \"{name}\" in Originalgröße öffnen",
    "Select image {imageName}" : "Bild {imageName} auswählen",
    "Open the \"{name}\" folder" : "Ordner \"{name}\" öffnen",
    "Back to {folder}" : "Zurück zu {folder}",
    "Go back" : "Zurückgehen",
    "Share this folder" : "Diesen Ordner teilen",
    "Dates" : "Termine",
    "Jump to specific date in list" : "Zu einem bestimmten Datum in der Liste springen",
    "Jump to {date}" : "Zu {date} springen",
    "Add to {destination}" : "Hinzufügen zu {destination}",
    "The destination folder is owned by {owner}" : "Der Zielordner gehört {owner}",
    "There are no photos or videos yet!" : "Es gibt noch keine Fotos oder Videos!",
    "_{years} year ago_::_{years} years ago_" : ["Vor {years} Jahr","Vor {years} Jahren"],
    "Enable squared photos view" : "Quadratische Fotoansicht aktivieren",
    "Delete source directory" : "Quellverzeichnis löschen",
    "Pick folder" : "Ordner auswählen",
    "Select a source folder for your media" : "Quellordner für deine Medien wählen",
    "All folders" : "Alle Ordner",
    "Add a Photos source for the timelines" : "In Fotos eine Quelle für die Zeitleisten hinzufügen",
    "Add folder" : "Ordner hinzufügen",
    "Select the default upload location for your media" : "Standardspeicherort für deine hochgeladenen Medien auswählen",
    "Home" : "Startseite",
    "Choose default Photos upload and Albums location" : "Den Standardspeicherort für das Hochladen von Fotos und Alben wählen",
    "Choose a different folder" : "Anderen Ordner wählen",
    "View" : "Ansicht",
    "Media folders" : "Medienordner",
    "Choose the folders from where photos and videos are shown." : "Ordner wählen, aus dem Fotos und Videos angezeigt werden.",
    "Upload folder" : "Hochladen-Ordner",
    "Choose the folder where photos and albums are uploaded to." : "Ordner wählen, in den Fotos und Videos hochgeladen werden.",
    "_%n photo_::_%n photos_" : ["%n Foto","%n Fotos"],
    "Unselect all" : "Auswahl aufheben",
    "Add photos to this album" : "Fotos zu diesem Album hinzufügen",
    "Manage collaborators for this album" : "Mitbearbeitende für dieses Album verwalten",
    "Open actions menu" : "Aktionsmenü öffnen",
    "Edit album details" : "Albumdetails bearbeiten",
    "Download all files in album" : "Alle Dateien im Album herunterladen",
    "Delete album" : "Album löschen",
    "Download selected files" : "Ausgewählte Dateien herunterladen",
    "Remove selection from album" : "Auswahl aus Album entfernen",
    "This album does not have any photos or videos yet!" : "Dieses Album enthält noch keine Fotos oder Videos!",
    "Add photos to {albumName}" : "Fotos hinzufügen zu {albumName}",
    "Manage collaborators" : "Mitarbeitende verwalten",
    "Save collaborators for this album." : "Mitbearbeitende für dieses Album speichern.",
    "Cover photo for album {albumName}" : "Titelbild für Album {albumName}",
    "There is no album yet!" : "Es gibt noch kein Album!",
    "This person could not be found" : "Diese Person konnte nicht gefunden werden",
    "Rename person" : "Person umbenennen",
    "Merge with different person" : "Mit einer anderen Person zusammenführen",
    "Download selected photos" : "Ausgwählte Fotos herunterladen",
    "Remove from favorites" : "Von Favoriten entfernen",
    "Remove person" : "Person entfernen",
    "Name of this person" : "Name dieser Person",
    "Save." : "Speichern",
    "Merge person" : "Person zusammenführen",
    "Move to different person" : "Zu einer anderen Person umziehen",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Foto an eine andere Person verschieben","Fotos an eine andere Person verschieben"],
    "_Remove photo from person_::_Remove photos from person_" : ["Foto von Person entfernen","Fotos von Person entfernen"],
    "This might take some time depending on the size of your photo library." : "Dies kann je nach Größe deiner Fotobibliothek einige Zeit dauern.",
    "Recognized people will show up here" : "Erkannte Menschen werden hier angezeigt werden",
    "This folder does not exist" : "Dieser Ordner existiert nicht",
    "Loading folders …" : "Lade Ordner…",
    "No photos in here" : "Keine Fotos vorhanden",
    "Taken on {date} at {time}" : "Aufgenommen am {date} um {time}",
    "This place does not have any photos or videos yet!" : "Dieser Ort enthält noch keine Fotos oder Videos!",
    "Add photos to this place" : "Fotos zu diesem Ort hinzufügen",
    "Cover photo for place {placeName}" : "Titelbild für Ort {placeName}",
    "There is no place yet!" : "Es gibt noch keinen Ort",
    "Cover photo for shared album {albumName}" : "Titelbild für das geteilte Album {albumName}",
    "Back to tags overview" : "Zurück zur Schlagwortübersicht",
    "No photos with this tag yet" : "Noch keine Fotos mit diesem Schlagwort",
    "No tags yet" : "Noch keine Schlagworte vorhanden",
    "Photos with tags will show up here" : "Fotos mit Tags werden hier angezeigt",
    "Popular tags" : "Beliebte Schlagwörter",
    "All tags" : "Alle Schlagworte",
    "One of the source folders does not exist" : "Einer der Quellordner existiert nicht",
    "Add to album" : "Zum Album hinzufügen",
    "Delete selection" : "Auswahl löschen",
    "No photos or videos in here" : "Hier gibt es keine Fotos oder Videos.",
    "Unassigned faces" : "Nicht zugewiesene Gesichter",
    "_%n photos_::_%n photos_" : ["%n Foto","%n Fotos"],
    "Failed to fetch collection." : "Sammlung konnte nicht abgerufen werden.",
    "Failed to fetch collections list." : "Sammlungsliste konnte nicht geladen werden.",
    "Failed to fetch faces list." : "Liste mit Gesichter konnte nicht geladen werden.",
    "All your media" : "Alle deine Medien",
    "Album {title}" : "Album {title}",
    "Shared Albums" : "Geteilte Alben",
    "Shared album {title}" : "Geteiltes Album {title}",
    "Public album {title}" : "Öffentliches Album {title}",
    "Tagged photos" : "Fotos mit Tags",
    "Tagged photo {title}" : "Fotos mit Schlagworten",
    "{title}'s face" : "{title}´s Gesicht",
    "{startDate} to {endDate}" : "{startDate} bis {endDate}",
    "Details" : "Details",
    "Failed to rename {oldName} to {faceName}" : "{oldName} konnte nicht in {faceName} umbenannt werden.",
    "Failed to delete {faceName}" : "{faceName} konnte nicht gelöscht werden",
    "Failed to delete {fileId}" : "{fileId} konnte nicht gelöscht werden",
    "Failed to delete {fileName}" : "{fileName} konnte nicht gelöscht werden",
    "Failed to set favorite state for {fileId}" : "Favoritenstatus für {fileId} konnte nicht gesetzt werden",
    "Failed to set favorite state for {fileName}" : "Favoritenstatus für {fileName} konnte nicht gesetzt werden",
    "Could not load photos folder" : "Fotos-Ordner konnte nicht geladen werden",
    "One of the source folders does not exists" : "Einer der Quellordner existiert nicht",
    "Add" : "Hinzufügen"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-32.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/photos/l10n/de.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Öffentlicher Link",
    "Photos" : "Fotos",
    "On This Day" : "An diesem Tag",
    "Your memories under your control" : "Deine Erinnerungen unter deiner Kontrolle",
    "All media" : "Alle Medien",
    "Videos" : "Videos",
    "Albums" : "Alben",
    "Collaborative albums" : "Kollaborative Alben",
    "People" : "Personen",
    "Folders" : "Ordner",
    "Favorites" : "Favoriten",
    "On this day" : "An diesem Tag",
    "Shared with you" : "Mit dir geteilt",
    "Tags" : "Schlagworte",
    "Places" : "Orte",
    "Map" : "Karte",
    "Photos settings" : "Fotos-Einstellungen",
    "Mark selection as favorite" : "Auswahl als Favoriten markieren",
    "Add selection to favorites" : "Auswahl zu Favoriten hinzufügen",
    "Remove selection from favorites" : "Auswahl aus Favoriten entfernen",
    "This name is already in use." : "Dieser Name wird bereits verwendet.",
    "\"{char}\" is not allowed inside a filename." : "\"{char}\" ist innerhalb eines Dateinamens nicht zulässig.",
    "Invalid filename." : "Ungültiger Dateiname.",
    "Name of the album" : "Name des Albums",
    "Location of the album" : "Ort des Albums",
    "Back" : "Zurück",
    "Add collaborators" : "Mitbearbeitende hinzufügen",
    "Save" : "Speichern",
    "Create album" : "Album erstellen",
    "Add to Album" : "Zum Album hinzufügen",
    "Add selection to album {albumName}" : "Auswahl zum Album {albumName} hinzufügen",
    "Shared by" : "Geteilt von",
    "Create a new album." : "Ein neues Album erstellen",
    "Create new album" : "Neues Album erstellen",
    "New album" : "Neues Album",
    "_%n item_::_%n photos and videos_" : ["%n Foto oder Video","%n Fotos und Videos"],
    "Failed to fetch collaborators list." : "Liste der Mitbearbeitenden konnte nicht abgerufen werden.",
    "Failed to update album." : "Album konnte nicht aktualisiert werden.",
    "Add people or groups who can edit your album" : "Personen oder Gruppen hinzufügen, die dein Album bearbeiten können",
    "Search people or groups" : "Nach Benutzer oder Gruppen suchen",
    "No recommendations. Start typing." : "Keine Vorschläge, beginne mit der Eingabe.",
    "Copy the public link" : "Den öffentlichen Link kopieren",
    "Public link copied!" : "Öffentlicher Link kopiert",
    "Copy public link" : "Öffentlichen Link kopieren",
    "Delete the public link" : "Den öffentlichen Link löschen",
    "Create public link share" : "Öffentlichen Link zum Teilen erstellen",
    "Share via public link" : "Als öffentlichen Link teilen",
    "This collection does not exist" : "Diese Sammlung existiert nicht",
    "An error occurred" : "Es ist ein Fehler aufgetreten",
    "No picture for this day" : "Kein Bild für diesen Tag",
    "Picture taken on this day will show up here." : "Ein Bild, das an diesem Tag aufgenommen wurde, wird hier angezeigt.",
    "More photos from this day" : "Weitere Bilder von diesem Tag",
    "_%n photos_::_%n photos_" : ["%n Foto","%n Fotos"],
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n nicht zugewiesenes Foto","%n nicht zugewiesene Fotos"],
    "Favorite" : "Favorit",
    "Favorite image, open the full size \"{name}\" image" : "Favorisiertes Bild, öffne das Bild \"{name}\" in Originalgröße",
    "Open the full size \"{name}\" image" : "Bild \"{name}\" in Originalgröße öffnen",
    "Select image {imageName}" : "Bild {imageName} auswählen",
    "Open the \"{name}\" folder" : "Ordner \"{name}\" öffnen",
    "Go back" : "Zurückgehen",
    "Select a custom date range" : "Einen benutzerdefinierten Datumsbereich auswählen",
    "Select a date range" : "Einen Datumsbereich auswählen",
    "Date range" : "Datumsbereich",
    "Select filters" : "Filter auswählen",
    "Dates" : "Termine",
    "Jump to specific date in list" : "Zu einem bestimmten Datum in der Liste springen",
    "Jump to {date}" : "Zu {date} springen",
    "Add to {destination}" : "Hinzufügen zu {destination}",
    "The destination folder is owned by {owner}" : "Der Zielordner gehört {owner}",
    "There are no photos or videos yet!" : "Es gibt noch keine Fotos oder Videos!",
    "_{years} year ago_::_{years} years ago_" : ["Vor {years} Jahr","Vor {years} Jahren"],
    "Squared photos view" : "Quadratische Fotoansicht",
    "Delete source directory" : "Quellverzeichnis löschen",
    "Pick folder" : "Ordner auswählen",
    "Select a source folder for your media" : "Quellordner für deine Medien wählen",
    "Media folders" : "Medienordner",
    "Choose the folders from where photos and videos are shown." : "Ordner wählen, aus dem Fotos und Videos angezeigt werden.",
    "All folders" : "Alle Ordner",
    "Add a Photos source for the timelines" : "In Fotos eine Quelle für die Zeitleisten hinzufügen",
    "Add folder" : "Ordner hinzufügen",
    "Home" : "Startseite",
    "Select the default upload location for your media" : "Standardspeicherort für deine hochgeladenen Medien auswählen",
    "Upload folder" : "Hochladen-Ordner",
    "General" : "Allgemein",
    "_%n photo_::_%n photos_" : ["%n Foto","%n Fotos"],
    "Unselect all" : "Auswahl aufheben",
    "Add photos to this album" : "Fotos zu diesem Album hinzufügen",
    "Manage collaborators for this album" : "Mitbearbeitende für dieses Album verwalten",
    "Open actions menu" : "Aktionsmenü öffnen",
    "Edit album details" : "Albumdetails bearbeiten",
    "Download all files in album" : "Alle Dateien im Album herunterladen",
    "Delete album" : "Album löschen",
    "Download selected files" : "Ausgewählte Dateien herunterladen",
    "Remove selection from album" : "Auswahl aus Album entfernen",
    "This album does not have any photos or videos yet!" : "Dieses Album enthält noch keine Fotos oder Videos!",
    "Add photos to {albumName}" : "Fotos hinzufügen zu {albumName}",
    "Manage collaborators" : "Mitarbeitende verwalten",
    "Save collaborators for this album." : "Mitbearbeitende für dieses Album speichern.",
    "Cover photo for album {albumName}" : "Titelbild für Album {albumName}",
    "There is no album yet!" : "Es gibt noch kein Album!",
    "This person could not be found" : "Diese Person konnte nicht gefunden werden",
    "Rename person" : "Person umbenennen",
    "Merge with different person" : "Mit einer anderen Person zusammenführen",
    "Download selected photos" : "Ausgwählte Fotos herunterladen",
    "Remove from favorites" : "Von Favoriten entfernen",
    "Remove person" : "Person entfernen",
    "Name of this person" : "Name dieser Person",
    "Save." : "Speichern",
    "Merge person" : "Person zusammenführen",
    "Move to different person" : "Zu einer anderen Person umziehen",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Foto an eine andere Person verschieben","Fotos an eine andere Person verschieben"],
    "_Remove photo from person_::_Remove photos from person_" : ["Foto von Person entfernen","Fotos von Person entfernen"],
    "This might take some time depending on the size of your photo library." : "Dies kann je nach Größe deiner Fotobibliothek einige Zeit dauern.",
    "Recognized people will show up here" : "Erkannte Menschen werden hier angezeigt werden",
    "This folder does not exist" : "Dieser Ordner existiert nicht",
    "Loading folders…" : "Lade Ordner…",
    "No photos in here" : "Keine Fotos vorhanden",
    "Taken on {date} at {time}" : "Aufgenommen am {date} um {time}",
    "This place does not have any photos or videos yet!" : "Dieser Ort enthält noch keine Fotos oder Videos!",
    "Add photos to this place" : "Fotos zu diesem Ort hinzufügen",
    "Cover photo for place {placeName}" : "Titelbild für Ort {placeName}",
    "There is no place yet!" : "Es gibt noch keinen Ort",
    "Cover photo for shared album {albumName}" : "Titelbild für das geteilte Album {albumName}",
    "Back to tags overview" : "Zurück zur Schlagwortübersicht",
    "No photos with this tag yet" : "Noch keine Fotos mit diesem Schlagwort",
    "No tags yet" : "Noch keine Schlagworte vorhanden",
    "Photos with tags will show up here" : "Fotos mit Tags werden hier angezeigt",
    "Popular tags" : "Beliebte Schlagwörter",
    "All tags" : "Alle Schlagworte",
    "Create new album from filters" : "Neues Album aus Filtern erstellen",
    "One of the source folders does not exist" : "Einer der Quellordner existiert nicht",
    "Add to album" : "Zum Album hinzufügen",
    "Delete selection" : "Auswahl löschen",
    "No photos or videos in here" : "Hier gibt es keine Fotos oder Videos.",
    "Unassigned faces" : "Nicht zugewiesene Gesichter",
    "Failed to fetch collection." : "Sammlung konnte nicht abgerufen werden.",
    "Failed to fetch collections list." : "Sammlungsliste konnte nicht geladen werden.",
    "Failed to fetch faces list." : "Liste mit Gesichter konnte nicht geladen werden.",
    "Error fetching files" : "Fehler beim Abrufen der Dateien",
    "All your media" : "Alle deine Medien",
    "Album {title}" : "Album {title}",
    "Shared Albums" : "Geteilte Alben",
    "Shared album {title}" : "Geteiltes Album {title}",
    "Public album {title}" : "Öffentliches Album {title}",
    "Tagged photos" : "Fotos mit Tags",
    "Tagged photo {title}" : "Fotos mit Schlagworten",
    "{title}'s face" : "{title}'s Gesicht",
    "Last week" : "Letzte Woche",
    "Last Month" : "Letzten Monat",
    "Custom…" : "Benutzerdefiniert…",
    "{startDate} to {endDate}" : "{startDate} bis {endDate}",
    "Details" : "Details",
    "Failed to add {fileBaseName} to collection {collectionFileName}" : "{fileBaseName} konnte nicht der Sammlung {collectionFileName} hinzugefügt werden",
    "Failed to delete {fileBaseName}" : "{fileBaseName} konnte nicht gelöscht werden",
    "Failed to create {collectionFileName}" : "{collectionFileName} konnte nicht erstellt werden",
    "Failed to rename {currentCollectionFileName} to {newCollectionFileName}" : "{currentCollectionFileName} konnte nicht in {newCollectionFileName} umbenannt werden.",
    "Failed to update properties of {collectionFileName} with {properties}" : "Die Eigenschaften von {collectionFileName} konnten nicht mit {properties} aktualisiert werden",
    "Delete collection" : "Sammlung löschen",
    "Leave shared album" : "Geteiltes Album verlassen",
    "Are you sure you want to delete {collectionName}? This action cannot be undone." : "Soll {collectionName} gelöscht werden? Das kann nicht rückgängig gemacht werden.",
    "Failed to delete {collectionFileName}" : "{collectionFileName} konnte nicht gelöscht werden",
    "Cancel" : "Abbrechen",
    "Confirm" : "Bestätigen",
    "Failed to move {fileBaseName} to person {faceName}" : "{fileBaseName} konnte nicht an {faceName} übertragen werden",
    "Failed to remove {fileBaseName}" : "{fileBaseName} konnte nicht entfernt werden",
    "Failed to rename {oldName} to {faceName}" : "{oldName} konnte nicht in {faceName} umbenannt werden.",
    "Failed to delete {faceName}" : "{faceName} konnte nicht gelöscht werden",
    "Failed to delete {fileId}" : "{fileId} konnte nicht gelöscht werden",
    "Failed to delete {fileName}" : "{fileName} konnte nicht gelöscht werden",
    "Failed to set favorite state for {fileId}" : "Favoritenstatus für {fileId} konnte nicht gesetzt werden",
    "Failed to set favorite state for {fileName}" : "Favoritenstatus für {fileName} konnte nicht gesetzt werden",
    "Could not load photos folder" : "Fotos-Ordner konnte nicht geladen werden",
    "Group" : "Gruppe",
    "Remove {collaboratorLabel} from the collaborators list" : "{collaboratorLabel} aus der Liste der Mitarbeitenden entfernen",
    "Back to {folder}" : "Zurück zu {folder}",
    "Share this folder" : "Diesen Ordner teilen",
    "Enable squared photos view" : "Quadratische Fotoansicht aktivieren",
    "Choose default Photos upload and Albums location" : "Den Standardspeicherort für das Hochladen von Fotos und Alben wählen",
    "Choose a different folder" : "Anderen Ordner wählen",
    "View" : "Ansicht",
    "Choose the folder where photos and albums are uploaded to." : "Ordner wählen, in den Fotos und Videos hochgeladen werden.",
    "Loading folders …" : "Lade Ordner…",
    "Add" : "Hinzufügen"
},
"nplurals=2; plural=(n != 1);");
